@@ -33,4 +33,13 @@ class BaseToolkit(BaseModel, ABC):
         raise NotImplementedError("Toolkit couldn't be used on UI")
 
     def get_toolkit(self, *args, **kwargs):
-        return self.__class__()
\ No newline at end of file
+        return self.__class__()
+
+
+class DiscoverableToolkit(BaseToolkit):
+    """A marker interface that indicates a toolkit should be autodiscovered.
+
+    Any toolkit that implements this interface will be automatically discovered
+    by the toolkit_provider
+    """
+    pass
