@@ -57,6 +57,7 @@ class Tool(BaseModel):
     name: str
     label: Optional[str] = None
     settings_config: Optional[bool] = False
+    description: Optional[str] = None
     user_description: Optional[str] = None
     config_class: Optional[Any] = Field(default=None, exclude=True)
     tool_class: Optional[Any] = Field(default=None, exclude=True)
@@ -80,6 +81,7 @@ class Tool(BaseModel):
         return cls(
             name=metadata.name,
             label=metadata.label or None,
+            description=metadata.description or None,
             user_description=metadata.user_description or None,
             config_class=config_class,
             settings_config=settings_config,
