@@ -184,13 +184,14 @@ def get_available_tools_configs() -> List[Type[CodeMieToolConfig]]:
 
 
 @functools.lru_cache(maxsize=128)
-def get_toolkit(name: str) -> Type[BaseToolkit]:
+def get_toolkit(name: str, raise_error: bool = False) -> type[BaseToolkit] | None:
     """
     Get a specific BaseToolkit subclass by its name.
     Results are cached for better performance.
 
     Args:
         name: The name of the toolkit class to find
+        raise_error: If True, raises ValueError when toolkit is not found. If False, returns None.
 
     Returns:
         The BaseToolkit subclass if found
@@ -203,7 +204,9 @@ def get_toolkit(name: str) -> Type[BaseToolkit]:
         definition = toolkit.get_definition()
         if definition and definition.toolkit == name:
             return toolkit
-    raise ValueError(f"No toolkit found with name: {name}")
+    if raise_error:
+        raise ValueError(f"No toolkit found with name: {name}")
+    return None
 
 
 @functools.lru_cache(maxsize=128)
@@ -245,7 +248,6 @@ def get_tool(name: str, raise_error: bool = False) -> Optional[Tool]:
     Args:
         name: The name of the tool to find
         raise_error: If True, raises ValueError when tool is not found. If False, returns None.
-                    Default is False for backward compatibility.
 
     Returns:
         The Tool object if found, None if not found and raise_error is False
