@@ -2,7 +2,7 @@ import ast
 import json
 import logging
 import re
-from typing import Type, Union, Dict
+from typing import Type, Union, Dict, Optional, Any
 
 from langchain_core.tools import ToolException
 from pydantic import BaseModel, ValidationError
@@ -35,6 +35,7 @@ def sanitize_string(input_string: str) -> str:
         (r'\b(?:\d{1,3}\.){3}\d{1,3}\b', '[IP_ADDRESS]'),  # IP addresses
         (r'\b(?:[A-Za-z0-9._%+-]+@[A-Za-z0-9.-]+\.[A-Z|a-z]{2,})\b', '[EMAIL]'),  # Email addresses
         (r'\b(api[_-]?key|access[_-]?token)(\s*[:=]\s*|\s+)(\S+)', r'\1\2[API_KEY]'),  # API keys and access tokens
+        (r'([?&])(api[_-]?key|key|access[_-]?token)=([A-Za-z0-9_\-]+)', r'\1\2=[API_KEY]'),  # API keys in URL query parameters
         (r'\b(?:\d{4}[-\s]?){4}\b', '[CREDIT_CARD]'),  # Credit card numbers
     ]
 
@@ -172,3 +173,38 @@ def humanize_error(error: Exception) -> str:
 def _format_pydantic_validation_loc(items):
   """Humanize the location field of a Pydantic validation error"""
   return ".".join(str(loc) for loc in items)
+
+
+def parse_and_escape_args(query: Union[str, Dict[str, Any]], item_type: str = None) -> Dict[str, Any]:
+    """
+    Parses arguments from string or dictionary input.
+    Handles JSON string parsing with proper error messaging.
+
+    Args:
+        query: Input query as either a JSON string or dictionary
+        item_type: Optional name of the item type for error messages
+
+    Returns:
+        Dictionary of parsed arguments or None if query is None
+
+    Raises:
+        ValueError: If query is not a valid JSON string or dictionary
+        ToolException: If parsing fails due to invalid format
+    """
+    if not query:
+        return {}
+
+    if isinstance(query, dict):
+        return query
+
+    if isinstance(query, str):
+        try:
+            # Remove markdown code block markers if present
+            query_str = query.replace("```json", "").replace("```", "").strip()
+            return json.loads(query_str)
+        except json.JSONDecodeError as e:
+            type_context = f" in {item_type}" if item_type else ""
+            raise ToolException(f"Invalid JSON format{type_context}: {str(e)}")
+
+    type_context = f"{item_type}" if item_type else "Input"
+    raise ToolException(f"{type_context} must be a JSON string or dict, got {type(query)}")
