@@ -6,6 +6,7 @@ from codemie_tools.base.models import CodeMieToolConfig
 
 class ConfluenceConfig(CodeMieToolConfig):
     url: str = Field(
+        default="",
         description="URL to your Confluence instance, e.g. http://confluence.example.com/",
         json_schema_extra={"placeholder": "https://confluence.example.com/"}
     )
@@ -15,6 +16,7 @@ class ConfluenceConfig(CodeMieToolConfig):
         json_schema_extra={"placeholder": "user@example.com"}
     )
     token: str = Field(
+        default="",
         description="API Access Token/ApiKey for authentication.",
         json_schema_extra={
             "placeholder": "Token/ApiKey",
@@ -29,10 +31,6 @@ class ConfluenceConfig(CodeMieToolConfig):
 
     @model_validator(mode='before')
     def validate_config(cls, values: Dict[str, Any]) -> Dict[str, Any]:
-        required_fields = ['url', 'token']
-        for field in required_fields:
-            if field not in values or not values[field]:
-                raise ValueError(f"{field} is a required field and must be provided.")
 
         if "is_cloud" in values:
             # Special handling for creating model from UI. is_cloud field is passed and should be passed to cloud
