@@ -1,7 +1,7 @@
 from typing import List
 
-from codemie_tools.base.base_toolkit import BaseToolkit
 from codemie_tools.base.models import ToolKit, ToolSet, Tool
+from codemie_tools.base.base_toolkit import DiscoverableToolkit
 from codemie_tools.core.project_management.confluence.tools import GenericConfluenceTool
 from codemie_tools.core.project_management.confluence.tools_vars import GENERIC_CONFLUENCE_TOOL
 from codemie_tools.core.project_management.jira.tools import GenericJiraIssueTool
@@ -17,15 +17,8 @@ class ProjectManagementToolkitUI(ToolKit):
     label: str = ToolSet.PROJECT_MANAGEMENT.value
 
 
-class ProjectManagementToolkit(BaseToolkit):
+class ProjectManagementToolkit(DiscoverableToolkit):
 
     @classmethod
     def get_definition(cls):
         return ProjectManagementToolkitUI()
-
-    @classmethod
-    def get_tools_ui_info(cls):
-        return cls.get_definition().model_dump()
-
-    def get_tools(self, *args, **kwargs):
-        return []
