@@ -25,6 +25,7 @@ from codemie_tools.data_management.file_system.tools_vars import (
     PYTHON_RUN_CODE_TOOL,
     DIFF_UPDATE_FILE_TOOL,
     REPLACE_STRING_TOOL,
+    CODE_EXECUTOR_TOOL,
 )
 
 logger = logging.getLogger(__name__)
@@ -42,6 +43,7 @@ class FileSystemToolkitUI(ToolKit):
         Tool.from_metadata(GENERATE_IMAGE_TOOL),
         Tool.from_metadata(DIFF_UPDATE_FILE_TOOL),
         Tool.from_metadata(REPLACE_STRING_TOOL),
+        Tool.from_metadata(CODE_EXECUTOR_TOOL),
     ]
     label: str = ToolSet.FILE_MANAGEMENT_LABEL.value
 
@@ -79,6 +81,10 @@ class FileSystemToolkit(BaseToolkit):
             ),
             GenerateImageTool(azure_dalle_config=self.azure_dalle_config),
             ReplaceStringTool(root_dir=self.root_directory),
+            # CodeExecutorTool(
+            #     file_repository=self.file_repository,
+            #     user_id=self.user_id
+            # ),
         ]
         return tools
 
