@@ -1,6 +1,7 @@
 import re
 from typing import Type, Optional
 
+from azure.devops.v7_0.git import CommentPosition, CommentThreadContext
 from azure.devops.v7_0.git.models import (
     GitRefUpdate,
     GitVersionDescriptor,
@@ -753,11 +754,15 @@ class GetWorkItemsTool(CodeMieTool):
 
 class CommentOnPullRequestInput(BaseModel):
     model_config = ConfigDict(arbitrary_types_allowed=True)
-    comment_query: str = Field(description="Follow the required formatting.")
+    pr_number: int = Field(description="Pull Request number")
+    comment: str = Field(description="Comment content")
+    file_path: str | None = Field(description="File path of the changed file")
+    line_number: int | None = Field(description="Line number for a changed file")
 
 
 class CommentOnPullRequestTool(CodeMieTool):
     """Tool for commenting on a pull request"""
+
     model_config = ConfigDict(arbitrary_types_allowed=True)
     client: Optional[AzureDevOpsClient] = Field(exclude=True, default=None)
     credentials: AzureDevOpsCredentials
@@ -765,25 +770,50 @@ class CommentOnPullRequestTool(CodeMieTool):
     description: str = COMMENT_ON_PULL_REQUEST_TOOL.description
     args_schema: Type[BaseModel] = CommentOnPullRequestInput
 
-    def execute(self, comment_query: str, *args):
+    def execute(
+        self,
+        pr_number: int,
+        comment: str,
+        file_path: str | None = None,
+        line_number: int | None = None,
+        *args,
+    ):
         if not self.client:
             self.client = AzureDevOpsClient(self.credentials)
-        
-        try:
-            pull_request_id = int(comment_query.split("\n\n")[0])
-            comment_text = comment_query[len(str(pull_request_id)) + 2 :]
 
-            comment = Comment(comment_type="text", content=comment_text)
+        try:
+            if file_path and not file_path.startswith("/"):
+                file_path = "/" + file_path
+
+            pr_comment = Comment(comment_type="text", content=comment)
+
+            pr_comment_context = None
+            if file_path and line_number:
+                pr_comment_context = CommentThreadContext(
+                    file_path=file_path,
+                    right_file_start=CommentPosition(
+                        line=line_number,
+                        offset=1,
+                    ),
+                    right_file_end=CommentPosition(
+                        line=line_number + 1,
+                        offset=1,
+                    ),
+                )
+
             comment_thread = GitPullRequestCommentThread(
-                comments=[comment], status="active"
+                comments=[pr_comment],
+                status="active",
+                thread_context=pr_comment_context,
             )
             self.client.client.create_thread(
                 comment_thread,
                 repository_id=self.client.repository_id,
-                pull_request_id=pull_request_id,
+                pull_request_id=pr_number,
                 project=self.client.project,
             )
-            return f"Commented on pull request {pull_request_id}"
+
+            return f"Commented on pull request {pr_number}"
         except Exception as e:
             msg = f"Unable to make comment due to error:\n{str(e)}"
             logger.error(msg)
