@@ -62,11 +62,25 @@ class EmailTool(CodeMieTool):
         Returns:
             Confirmation message on success
         """
+
         try:
             host, port = self.config.url.split(":")
+        except Exception:
+            raise ValueError(
+                "Please provide valid SMTP url."
+            )
+
+        from_email = from_email if from_email else self.config.smtp_username
+
+        if not from_email or not host or not port or not self.config.smtp_password:
+            raise ValueError(
+                "Please provide valid SMTP configuration before using the tool. "
+            )
+
+        try:
             msg = MIMEMultipart("alternative")
             msg["Subject"] = subject
-            msg["From"] = from_email if from_email else self.config.smtp_username
+            msg["From"] = from_email
             msg["To"] = ", ".join(recipient_emails)
             if cc_emails:
                 msg["Cc"] = ", ".join(cc_emails)
