@@ -56,6 +56,11 @@ class TelegramTool(CodeMieTool):
                 "Telegram config is provided set. Please set it before using the tool."
             )
 
+        if not self.config.bot_token:
+            raise ValueError(
+                "Telegram token is not set. Please provide it before using the tool."
+            )
+
         base_url = f"https://api.telegram.org/bot{self.config.bot_token}"
         full_url = f"{base_url}{relative_url}"
         headers = {"Content-Type": "application/json"}
